--[[
Copyright 2013 João Cardoso
PetTracker Broker is distributed under the terms of the GNU General Public License (Version 3).
As a special exception, the copyright holders of this addon do not give permission to
redistribute and/or modify it.

This addon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the addon. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.

This file is part of PetTracker Broker.
--]]

local ADDON = ...
local Addon = PetTracker
local Drop = CreateFrame('Frame', ADDON .. 'Drop', nil, 'UIDropDownMenuTemplate')
local Tip = CreateFrame('Frame', ADDON .. 'Tip', UIParent, 'GameTooltipTemplate')
local Broker = Addon:NewModule('Broker', LibStub('LibDataBroker-1.1'):NewDataObject('PetTracker', {
	type = 'data source',
	icon = 'Interface/Icons/Tracking_WildPet',
	label = PETS
}))


--[[ Startup ]]--

function Broker:Startup()
	local tracker = Addon.Tracker(Tip)
	tracker.Title:SetPoint('TOP', Tip, -25, -10)
	tracker.Bar:SetWidth(200)
	tracker.ShowSpecies = function()
		tracker.__index.ShowSpecies(tracker)
		Tip:SetHeight(tracker:Count() * 20 + 60)
	end

	Tip:SetSize(230, 1)
	UIDropDownMenu_Initialize(Drop, self.ShowOptions, 'MENU')
	self.tracker = tracker
end


--[[ Frame Events ]]--

function Broker:OnEnter()
	Tip:ClearAllPoints()
	Tip:Show()

	if (self:GetBottom() < UIParent:GetHeight() / 2) then
		Tip:SetPoint('BOTTOM', self, 'TOP')
	else
		Tip:SetPoint('TOP', self, 'BOTTOM')
	end
end

function Broker:OnLeave()
	Tip:Hide()
end

function Broker:OnClick(button)
	if button == 'RightButton' then
		ToggleDropDownMenu(1, nil, Drop, self, 0, 0)
	else
		Addon.Tracker:Toggle()
	end
end


--[[ Other Events ]]--

function Broker:ShowOptions()
	Addon.Tracker:ShowOptions('Track Pets')
end

function Broker:TrackingChanged()
	local progress = Addon.Journal:GetCurrentProgress()
	local owned = 0

	for i = Addon.MaxQuality, 1, -1 do
		owned = owned + progress[i].total
	end

	self.text = owned .. '/' .. progress.total
	self.tracker:Update()
end